# -*- coding: utf-8 -*-
'''
Created on Dec 8, 2012

@author: tuxskar
'''

import unittest

class controllers_test(unittest.TestCase):
    pass


if __name__ == '__main__':
    unittest.main()
